@@ -14,7 +14,7 @@
 #include "../helper/message-display.h"
 #include "../helper/memory-display.h"
 #include "../helper/printing.h"
-#include "../helper/string.h"
+#include "../libgammu/misc/string.h"
 #include "../helper/cmdline.h"
 
 /**
