@@ -23,7 +23,7 @@
 
 #include "../core.h"
 
-#include "../../helper/string.h"
+#include "../../libgammu/misc/string.h"
 
 #ifndef PATH_MAX
 #ifdef MAX_PATH
